@@ -24,7 +24,9 @@ check_key <- function(x, key = character(0), na_distinct = FALSE, x_name = NULL)
 
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
   chk_string(x_name)
-  if(!length(key)) return(invisible(x)) # to ensure not tripped up by sf objects.
+  if (!length(key)) {
+    return(invisible(x))
+  } # to ensure not tripped up by sf objects.
 
   check_names(x, key, x_name = x_name)
 
