@@ -24,7 +24,9 @@ chk_equivalent <- function(x, y, tolerance = sqrt(.Machine$double.eps),
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   y_name <- as_label(y)
-  abort_chk(x_name, " must be equivalent to: ", y_name, x = x, y = y)
+  obj_of <- if(grepl("^<", y_name)) "the y object of class " else NULL
+  abort_chk(x_name, " must be equivalent to ",
+            obj_of, y_name, x = x, y = y)
 }
 
 #' @describeIn chk_equivalent Validate Equivalent
