@@ -21,13 +21,12 @@
 #' @export
 chk_not_any_na <- function(x, x_name = NULL) {
   if (vld_not_any_na(x)) {
-    return(invisible())
+    return(invisible(x))
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
   abort_chk(x_name, " must not have any missing values", x = x)
 }
 
-
 #' @describeIn chk_not_any_na Validate Not Any Missing Values
 #'
 #' @examples
